@@ -32,13 +32,13 @@ class RelatedDrives(PluginTemplateExtension):
         for lv in lvs:
             logger.warning(f'{lv.vg}')
             lvm_list.append(LVMModel(lv.lv_name, lv.path, lv.fs, lv.size, lv.vg.vg_name))
-            # physical_volumes = PhysicalVolume.objects.all()
-            # physical_volume_list = []
-            # for physical_volume in physical_volumes:
-            #     if physical_volume.vg == vg:
-            #         physical_volume_list.append(physical_volume.pv_name)
-            #         lvm_model = lvm_list[-1]
-            #         lvm_model.pv_list = physical_volume_list
+            physical_volumes = PhysicalVolume.objects.all()
+            physical_volume_list = []
+            for physical_volume in physical_volumes:
+                if physical_volume.vg == lv.vg:
+                    physical_volume_list.append(physical_volume.pv_name)
+                    lvm_model = lvm_list[-1]
+                    lvm_model.pv_list = physical_volume_list
             #         partitions = Partition.objects.all()
             #         partition_list = []
             #         for partition in partitions:
